@@ -11,4 +11,8 @@ def create_optimizer_by_name(name, *args):
     name = name.lower()
     if name not in _optimizers_dict:
         raise KeyError(f'Invalid metric name, we support {list(_optimizers_dict.keys())}.')
-    return _optimizers_dict[name](*args, lr=1e-3)
\ No newline at end of file
+    if name == 'sgd':
+        lr = 1e-2
+    else:
+        lr = 1e-3
+    return _optimizers_dict[name](*args, lr)
\ No newline at end of file
